@@ -316,7 +316,8 @@ int PgpoolMain(bool discard_status, bool clear_memcache_oidmaps)
 		}
 
 		ereport (LOG,
-				 (errmsg("watchdog process is initialized")));
+				 (errmsg("watchdog process is initialized"),
+				 errdetail("watchdog messaging data version: %s",WD_MESSAGE_DATA_VERSION)));
 		/*
 		 * initialize the lifecheck process
 		 */
@@ -643,6 +644,7 @@ bool register_node_operation_request(POOL_REQUEST_KIND kind, int* node_id_set, i
 	if((Req_info->request_queue_tail - MAX_REQUEST_QUEUE_SIZE) == Req_info->request_queue_head)
 	{
 		pool_semaphore_unlock(REQUEST_INFO_SEM);
+		POOL_SETMASK(&oldmask);
 		return false;
 	}
 	Req_info->request_queue_tail++;
