@@ -822,6 +822,39 @@ rewrite_timestamp(POOL_CONNECTION_POOL *backend, Node *node,
 			}
 		}
 	}
+	else if (IsA(stmt, CreateTableAsStmt))
+	{
+		CreateTableAsStmt *c_stmt = (CreateTableAsStmt *) stmt;
+
+		/*
+		 * CREATE TABLE t1 AS SELECT now();
+		 */
+		if (IsA(c_stmt->query, SelectStmt) && c_stmt->relkind == OBJECT_TABLE)
+		{
+			/* rewrite params */
+			raw_expression_tree_walker(
+									   (Node *) c_stmt->query,
+									   rewrite_timestamp_walker, (void *) &ctx);
+
+			rewrite = ctx.rewrite;
+		}
+	}
+	else if (IsA(stmt, SelectStmt))
+	{
+		SelectStmt *s_stmt = (SelectStmt *) stmt;
+
+		/*
+		 * SELECT now() INTO t1;
+		 */
+		if (s_stmt->intoClause)
+		{
+			raw_expression_tree_walker(
+									   (Node *) s_stmt,
+									   rewrite_timestamp_walker, (void *) &ctx);
+		}
+
+		rewrite = ctx.rewrite;
+	}
 	else
 		;
 
